@@ -26,6 +26,7 @@ V1_10_0 = 'v1.10.0'
 V1_10_1 = 'v1.10.1'
 V1_10_2 = 'v1.10.2'
 V1_10_3 = 'v1.10.3'
+V1_10_4 = 'v1.10.4'
 
 
 LINUX = 'linux'
@@ -304,6 +305,7 @@ install_v1_10_0 = functools.partial(install_from_source_code_release, V1_10_0)
 install_v1_10_1 = functools.partial(install_from_source_code_release, V1_10_1)
 install_v1_10_2 = functools.partial(install_from_source_code_release, V1_10_2)
 install_v1_10_3 = functools.partial(install_from_source_code_release, V1_10_3)
+install_v1_10_4 = functools.partial(install_from_source_code_release, V1_10_4)
 
 
 INSTALL_FUNCTIONS = {
@@ -324,6 +326,7 @@ INSTALL_FUNCTIONS = {
         V1_10_1: install_v1_10_1,
         V1_10_2: install_v1_10_2,
         V1_10_3: install_v1_10_3,
+        V1_10_4: install_v1_10_4,
     },
     OSX: {
         V1_9_14: install_v1_9_14,
@@ -342,6 +345,7 @@ INSTALL_FUNCTIONS = {
         V1_10_1: install_v1_10_1,
         V1_10_2: install_v1_10_2,
         V1_10_3: install_v1_10_3,
+        V1_10_4: install_v1_10_4,
     }
 }
 
